"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from enum import Enum
from gusto_app_integration.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PayrollType(str, Enum):
    r"""Whether it is regular pay period or transition pay period."""

    REGULAR = "regular"
    TRANSITION = "transition"


class PayPeriodPayrollTypedDict(TypedDict):
    r"""Information about the payroll for the pay period."""

    payroll_uuid: NotRequired[str]
    r"""The UUID of the payroll for this pay period."""
    check_date: NotRequired[str]
    r"""The date on which employees will be paid for the payroll if the payroll is submitted on time."""
    processed: NotRequired[bool]
    r"""Whether or not the payroll has been successfully processed. Note that processed payrolls cannot be updated. Additionally, a payroll is not guaranteed to be processed just because the payroll deadline has passed. Late payrolls are not uncommon. Conversely, users may choose to run payroll before the payroll deadline."""
    payroll_deadline: NotRequired[datetime]
    r"""The date by which payroll should be run for employees to be paid on time. Payroll data, such as time and attendance data, should be submitted on or before this date."""
    payroll_type: NotRequired[PayrollType]
    r"""Whether it is regular pay period or transition pay period."""


class PayPeriodPayroll(BaseModel):
    r"""Information about the payroll for the pay period."""

    payroll_uuid: Optional[str] = None
    r"""The UUID of the payroll for this pay period."""

    check_date: Optional[str] = None
    r"""The date on which employees will be paid for the payroll if the payroll is submitted on time."""

    processed: Optional[bool] = None
    r"""Whether or not the payroll has been successfully processed. Note that processed payrolls cannot be updated. Additionally, a payroll is not guaranteed to be processed just because the payroll deadline has passed. Late payrolls are not uncommon. Conversely, users may choose to run payroll before the payroll deadline."""

    payroll_deadline: Optional[datetime] = None
    r"""The date by which payroll should be run for employees to be paid on time. Payroll data, such as time and attendance data, should be submitted on or before this date."""

    payroll_type: Optional[PayrollType] = None
    r"""Whether it is regular pay period or transition pay period."""


class PayPeriodTypedDict(TypedDict):
    r"""The representation of a pay period."""

    start_date: NotRequired[str]
    r"""The start date, inclusive, of the pay period."""
    end_date: NotRequired[str]
    r"""The end date, inclusive, of the pay period."""
    pay_schedule_uuid: NotRequired[str]
    r"""A unique identifier of the pay schedule to which the pay period belongs."""
    payroll: NotRequired[PayPeriodPayrollTypedDict]
    r"""Information about the payroll for the pay period."""


class PayPeriod(BaseModel):
    r"""The representation of a pay period."""

    start_date: Optional[str] = None
    r"""The start date, inclusive, of the pay period."""

    end_date: Optional[str] = None
    r"""The end date, inclusive, of the pay period."""

    pay_schedule_uuid: Optional[str] = None
    r"""A unique identifier of the pay schedule to which the pay period belongs."""

    payroll: Optional[PayPeriodPayroll] = None
    r"""Information about the payroll for the pay period."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FlsaStatusType(str, Enum):
    r"""The FLSA status for this compensation. Salaried ('Exempt') employees are paid a fixed salary every pay period. Salaried with overtime ('Salaried Nonexempt') employees are paid a fixed salary every pay period, and receive overtime pay when applicable. Hourly ('Nonexempt') employees are paid for the hours they work, and receive overtime pay when applicable. Commissioned employees ('Commission Only Exempt') earn wages based only on commission. Commissioned with overtime ('Commission Only Nonexempt') earn wages based on commission, and receive overtime pay when applicable. Owners ('Owner') are employees that own at least twenty percent of the company."""

    EXEMPT = "Exempt"
    SALARIED_NONEXEMPT = "Salaried Nonexempt"
    NONEXEMPT = "Nonexempt"
    OWNER = "Owner"
    COMMISSION_ONLY_EXEMPT = "Commission Only Exempt"
    COMMISSION_ONLY_NONEXEMPT = "Commission Only Nonexempt"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from gusto_app_integration import models, utils
from gusto_app_integration._hooks import HookContext
from gusto_app_integration.types import OptionalNullable, UNSET
from typing import Any, Mapping, Optional


class TimeOffPolicies(BaseSDK):
    def calculate_accruing_time_off_hours(
        self,
        *,
        payroll_id: str,
        employee_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        regular_hours_worked: Optional[float] = None,
        overtime_hours_worked: Optional[float] = None,
        double_overtime_hours_worked: Optional[float] = None,
        pto_hours_used: Optional[float] = None,
        sick_hours_used: Optional[float] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccruingTimeOffHourObject:
        r"""Calculate accruing time off hours

        Returns a list of accruing time off for each time off policy associated with the employee.

        Factors affecting the accrued hours:
        * the time off policy accrual method (whether they get pay per hour worked, per hour paid, with / without overtime, accumulate time off based on pay period / calendar year / anniversary)
        * how many hours of work during this pay period
        * how many hours of PTO / sick hours taken during this pay period (for per hour paid policies only)
        * company pay schedule frequency (for per pay period)

        If none of the parameters is passed in, the accrued time off hour will be 0.

        scope: `payrolls:read`

        :param payroll_id: The UUID of the payroll
        :param employee_id: The UUID of the employee
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param regular_hours_worked: regular hours worked in this pay period
        :param overtime_hours_worked: overtime hours worked in this pay period
        :param double_overtime_hours_worked: double overtime hours worked in this pay period
        :param pto_hours_used: paid time off hours used in this pay period
        :param sick_hours_used: sick hours used in this pay period
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequest(
            payroll_id=payroll_id,
            employee_id=employee_id,
            x_gusto_api_version=x_gusto_api_version,
            request_body=models.PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody(
                regular_hours_worked=regular_hours_worked,
                overtime_hours_worked=overtime_hours_worked,
                double_overtime_hours_worked=double_overtime_hours_worked,
                pto_hours_used=pto_hours_used,
                sick_hours_used=sick_hours_used,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1/payrolls/{payroll_id}/employees/{employee_id}/calculate_accruing_time_off_hours",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="post-v1-payrolls-payroll_id-calculate_accruing_time_off_hours",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.AccruingTimeOffHourObject)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnprocessableEntityErrorObjectData
            )
            raise models.UnprocessableEntityErrorObject(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def calculate_accruing_time_off_hours_async(
        self,
        *,
        payroll_id: str,
        employee_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        regular_hours_worked: Optional[float] = None,
        overtime_hours_worked: Optional[float] = None,
        double_overtime_hours_worked: Optional[float] = None,
        pto_hours_used: Optional[float] = None,
        sick_hours_used: Optional[float] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AccruingTimeOffHourObject:
        r"""Calculate accruing time off hours

        Returns a list of accruing time off for each time off policy associated with the employee.

        Factors affecting the accrued hours:
        * the time off policy accrual method (whether they get pay per hour worked, per hour paid, with / without overtime, accumulate time off based on pay period / calendar year / anniversary)
        * how many hours of work during this pay period
        * how many hours of PTO / sick hours taken during this pay period (for per hour paid policies only)
        * company pay schedule frequency (for per pay period)

        If none of the parameters is passed in, the accrued time off hour will be 0.

        scope: `payrolls:read`

        :param payroll_id: The UUID of the payroll
        :param employee_id: The UUID of the employee
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param regular_hours_worked: regular hours worked in this pay period
        :param overtime_hours_worked: overtime hours worked in this pay period
        :param double_overtime_hours_worked: double overtime hours worked in this pay period
        :param pto_hours_used: paid time off hours used in this pay period
        :param sick_hours_used: sick hours used in this pay period
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequest(
            payroll_id=payroll_id,
            employee_id=employee_id,
            x_gusto_api_version=x_gusto_api_version,
            request_body=models.PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody(
                regular_hours_worked=regular_hours_worked,
                overtime_hours_worked=overtime_hours_worked,
                double_overtime_hours_worked=double_overtime_hours_worked,
                pto_hours_used=pto_hours_used,
                sick_hours_used=sick_hours_used,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/payrolls/{payroll_id}/employees/{employee_id}/calculate_accruing_time_off_hours",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="post-v1-payrolls-payroll_id-calculate_accruing_time_off_hours",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.AccruingTimeOffHourObject)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnprocessableEntityErrorObjectData
            )
            raise models.UnprocessableEntityErrorObject(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from gusto_app_integration.types import BaseModel
from gusto_app_integration.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBodyTypedDict(
    TypedDict
):
    regular_hours_worked: NotRequired[float]
    r"""regular hours worked in this pay period"""
    overtime_hours_worked: NotRequired[float]
    r"""overtime hours worked in this pay period"""
    double_overtime_hours_worked: NotRequired[float]
    r"""double overtime hours worked in this pay period"""
    pto_hours_used: NotRequired[float]
    r"""paid time off hours used in this pay period"""
    sick_hours_used: NotRequired[float]
    r"""sick hours used in this pay period"""


class PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody(BaseModel):
    regular_hours_worked: Optional[float] = None
    r"""regular hours worked in this pay period"""

    overtime_hours_worked: Optional[float] = None
    r"""overtime hours worked in this pay period"""

    double_overtime_hours_worked: Optional[float] = None
    r"""double overtime hours worked in this pay period"""

    pto_hours_used: Optional[float] = None
    r"""paid time off hours used in this pay period"""

    sick_hours_used: Optional[float] = None
    r"""sick hours used in this pay period"""


class PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestTypedDict(TypedDict):
    payroll_id: str
    r"""The UUID of the payroll"""
    employee_id: str
    r"""The UUID of the employee"""
    request_body: (
        PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBodyTypedDict
    )
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequest(BaseModel):
    payroll_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the payroll"""

    employee_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the employee"""

    request_body: Annotated[
        PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from gusto_app_integration import models, utils
from gusto_app_integration._hooks import HookContext
from gusto_app_integration.types import OptionalNullable, UNSET
from typing import List, Mapping, Optional


class PaySchedules(BaseSDK):
    def list(
        self,
        *,
        company_id: str,
        page: Optional[int] = None,
        per: Optional[int] = None,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.PayScheduleList]:
        r"""Get the pay schedules for a company

        The pay schedule object in Gusto captures the details of when employees work and when they should be paid. A company can have multiple pay schedules.

        scope: `pay_schedules:read`

        :param company_id: The UUID of the company
        :param page: The page that is requested. When unspecified, will load all objects unless endpoint forces pagination.
        :param per: Number of objects per page. For majority of endpoints will default to 25
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPaySchedulesRequest(
            company_id=company_id,
            page=page,
            per=per,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/companies/{company_id}/pay_schedules",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_schedules",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.PayScheduleList])
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        company_id: str,
        page: Optional[int] = None,
        per: Optional[int] = None,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.PayScheduleList]:
        r"""Get the pay schedules for a company

        The pay schedule object in Gusto captures the details of when employees work and when they should be paid. A company can have multiple pay schedules.

        scope: `pay_schedules:read`

        :param company_id: The UUID of the company
        :param page: The page that is requested. When unspecified, will load all objects unless endpoint forces pagination.
        :param per: Number of objects per page. For majority of endpoints will default to 25
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPaySchedulesRequest(
            company_id=company_id,
            page=page,
            per=per,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/companies/{company_id}/pay_schedules",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_schedules",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.PayScheduleList])
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get(
        self,
        *,
        company_id: str,
        pay_schedule_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PayScheduleObject:
        r"""Get a pay schedule

        The pay schedule object in Gusto captures the details of when employees work and when they should be paid. A company can have multiple pay schedules.

        scope: `pay_schedules:read`

        :param company_id: The UUID of the company
        :param pay_schedule_id: The UUID of the pay schedule
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest(
            company_id=company_id,
            pay_schedule_id=pay_schedule_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/companies/{company_id}/pay_schedules/{pay_schedule_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_schedules-pay_schedule_id",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PayScheduleObject)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_async(
        self,
        *,
        company_id: str,
        pay_schedule_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PayScheduleObject:
        r"""Get a pay schedule

        The pay schedule object in Gusto captures the details of when employees work and when they should be paid. A company can have multiple pay schedules.

        scope: `pay_schedules:read`

        :param company_id: The UUID of the company
        :param pay_schedule_id: The UUID of the pay schedule
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest(
            company_id=company_id,
            pay_schedule_id=pay_schedule_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/companies/{company_id}/pay_schedules/{pay_schedule_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_schedules-pay_schedule_id",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PayScheduleObject)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get_pay_periods(
        self,
        *,
        company_id: str,
        start_date: Optional[str] = None,
        end_date: Optional[str] = None,
        payroll_types: Optional[str] = None,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.PayPeriod]:
        r"""Get pay periods for a company

        Pay periods are the foundation of payroll. Compensation, time & attendance, taxes, and expense reports all rely on when they happened. To begin submitting information for a given payroll, we need to agree on the time period.

        By default, this endpoint returns pay periods starting from 6 months ago to the date today.  Use the `start_date` and `end_date` parameters to change the scope of the response.  End dates can be up to 3 months in the future and there is no limit on start dates.

        Starting in version '2023-04-01', the eligible_employees attribute was removed from the response.  The eligible employees for a payroll are determined by the employee_compensations returned from the payrolls#prepare endpoint.

        scope: `payrolls:read`

        :param company_id: The UUID of the company
        :param start_date:
        :param end_date: If left empty, defaults to today's date.
        :param payroll_types: regular and/or transition. Multiple options are comma separated. The default is regular pay periods if nothing is passed in.
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPayPeriodsRequest(
            company_id=company_id,
            start_date=start_date,
            end_date=end_date,
            payroll_types=payroll_types,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/companies/{company_id}/pay_periods",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_periods",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.PayPeriod])
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_pay_periods_async(
        self,
        *,
        company_id: str,
        start_date: Optional[str] = None,
        end_date: Optional[str] = None,
        payroll_types: Optional[str] = None,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.PayPeriod]:
        r"""Get pay periods for a company

        Pay periods are the foundation of payroll. Compensation, time & attendance, taxes, and expense reports all rely on when they happened. To begin submitting information for a given payroll, we need to agree on the time period.

        By default, this endpoint returns pay periods starting from 6 months ago to the date today.  Use the `start_date` and `end_date` parameters to change the scope of the response.  End dates can be up to 3 months in the future and there is no limit on start dates.

        Starting in version '2023-04-01', the eligible_employees attribute was removed from the response.  The eligible employees for a payroll are determined by the employee_compensations returned from the payrolls#prepare endpoint.

        scope: `payrolls:read`

        :param company_id: The UUID of the company
        :param start_date:
        :param end_date: If left empty, defaults to today's date.
        :param payroll_types: regular and/or transition. Multiple options are comma separated. The default is regular pay periods if nothing is passed in.
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPayPeriodsRequest(
            company_id=company_id,
            start_date=start_date,
            end_date=end_date,
            payroll_types=payroll_types,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/companies/{company_id}/pay_periods",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_periods",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.PayPeriod])
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get_unprocessed_termination_pay_periods(
        self,
        *,
        company_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.UnprocessedTerminationPayPeriod]:
        r"""Get termination pay periods for a company

        When a payroll admin terminates an employee and selects \"Dismissal Payroll\" as the employee's final payroll, their last pay period will appear on the list.

        This endpoint returns the unprocessed pay periods for past and future terminated employees in a given company.

        scope: `payrolls:read`

        :param company_id: The UUID of the company
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequest(
            company_id=company_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/companies/{company_id}/pay_periods/unprocessed_termination_pay_periods",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-unprocessed_termination_pay_periods",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, List[models.UnprocessedTerminationPayPeriod]
            )
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_unprocessed_termination_pay_periods_async(
        self,
        *,
        company_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.UnprocessedTerminationPayPeriod]:
        r"""Get termination pay periods for a company

        When a payroll admin terminates an employee and selects \"Dismissal Payroll\" as the employee's final payroll, their last pay period will appear on the list.

        This endpoint returns the unprocessed pay periods for past and future terminated employees in a given company.

        scope: `payrolls:read`

        :param company_id: The UUID of the company
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequest(
            company_id=company_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/companies/{company_id}/pay_periods/unprocessed_termination_pay_periods",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-unprocessed_termination_pay_periods",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(
                http_res.text, List[models.UnprocessedTerminationPayPeriod]
            )
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get_assignments(
        self,
        *,
        company_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PayScheduleAssignment:
        r"""Get pay schedule assignments for a company

        This endpoint returns the current pay schedule assignment for a company, with pay schedule and employee/department mappings depending on the pay schedule type.

        scope: `pay_schedules:read`

        :param company_id: The UUID of the company
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequest(
            company_id=company_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/companies/{company_id}/pay_schedules/assignments",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_schedules-assignments",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PayScheduleAssignment)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_assignments_async(
        self,
        *,
        company_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PayScheduleAssignment:
        r"""Get pay schedule assignments for a company

        This endpoint returns the current pay schedule assignment for a company, with pay schedule and employee/department mappings depending on the pay schedule type.

        scope: `pay_schedules:read`

        :param company_id: The UUID of the company
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequest(
            company_id=company_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/companies/{company_id}/pay_schedules/assignments",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-companies-company_id-pay_schedules-assignments",
                oauth2_scopes=[],
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.PayScheduleAssignment)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_app_integration.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DefaultValueTypedDict(TypedDict):
    value: NotRequired[str]
    type: NotRequired[str]


class DefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class EmployeeDeductionTypedDict(TypedDict):
    r"""The amount to be deducted, per pay period, from the employee's pay."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[DefaultValueTypedDict]
    choices: NotRequired[List[str]]


class EmployeeDeduction(BaseModel):
    r"""The amount to be deducted, per pay period, from the employee's pay."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[DefaultValue] = None

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsDefaultValueTypedDict(TypedDict):
    value: NotRequired[str]
    type: NotRequired[str]


class BenefitTypeRequirementsDefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class BenefitTypeRequirementsContributionTypedDict(TypedDict):
    r"""An object representing the type and value of the company contribution."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[BenefitTypeRequirementsDefaultValueTypedDict]
    choices: NotRequired[List[str]]


class BenefitTypeRequirementsContribution(BaseModel):
    r"""An object representing the type and value of the company contribution."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[BenefitTypeRequirementsDefaultValue] = None

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsDeductAsPercentageDefaultValueTypedDict(TypedDict):
    value: NotRequired[str]
    type: NotRequired[str]


class BenefitTypeRequirementsDeductAsPercentageDefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class DeductAsPercentageTypedDict(TypedDict):
    r"""Whether the employee deduction amount should be treated as a percentage to be deducted from each payroll."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[
        BenefitTypeRequirementsDeductAsPercentageDefaultValueTypedDict
    ]
    choices: NotRequired[List[str]]


class DeductAsPercentage(BaseModel):
    r"""Whether the employee deduction amount should be treated as a percentage to be deducted from each payroll."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[BenefitTypeRequirementsDeductAsPercentageDefaultValue] = (
        None
    )

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsCatchUpDefaultValueTypedDict(TypedDict):
    value: NotRequired[str]
    type: NotRequired[str]


class BenefitTypeRequirementsCatchUpDefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class CatchUpTypedDict(TypedDict):
    r"""Whether the employee should use a benefit’s 'catch up' rate. Only Roth 401k and 401k benefits use this value for employees over 50."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[BenefitTypeRequirementsCatchUpDefaultValueTypedDict]
    choices: NotRequired[List[str]]


class CatchUp(BaseModel):
    r"""Whether the employee should use a benefit’s 'catch up' rate. Only Roth 401k and 401k benefits use this value for employees over 50."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[BenefitTypeRequirementsCatchUpDefaultValue] = None

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsLimitOptionDefaultValueTypedDict(TypedDict):
    value: NotRequired[str]
    type: NotRequired[str]


class BenefitTypeRequirementsLimitOptionDefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class LimitOptionTypedDict(TypedDict):
    r"""Some benefits require additional information to determine their limit. For example, for an HSA benefit, the limit option should be either 'Family' or 'Individual'. For a Dependent Care FSA benefit, the limit option should be either 'Joint Filing or Single' or 'Married and Filing Separately'."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[BenefitTypeRequirementsLimitOptionDefaultValueTypedDict]
    choices: NotRequired[List[str]]


class LimitOption(BaseModel):
    r"""Some benefits require additional information to determine their limit. For example, for an HSA benefit, the limit option should be either 'Family' or 'Individual'. For a Dependent Care FSA benefit, the limit option should be either 'Joint Filing or Single' or 'Married and Filing Separately'."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[BenefitTypeRequirementsLimitOptionDefaultValue] = None

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValueTypedDict(
    TypedDict
):
    value: NotRequired[str]
    type: NotRequired[str]


class BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class CompanyContributionAnnualMaximumTypedDict(TypedDict):
    r"""The maximum company contribution amount per year. A null value signifies no limit."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[
        BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValueTypedDict
    ]
    choices: NotRequired[List[str]]


class CompanyContributionAnnualMaximum(BaseModel):
    r"""The maximum company contribution amount per year. A null value signifies no limit."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[
        BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValue
    ] = None

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValueTypedDict(TypedDict):
    value: NotRequired[str]
    type: NotRequired[str]


class BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class CoverageSalaryMultiplierTypedDict(TypedDict):
    r"""The coverage amount as a multiple of the employee's salary. Only applicable for Group Term Life benefits. Note: cannot be set if coverage amount is also set."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[
        BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValueTypedDict
    ]
    choices: NotRequired[List[str]]


class CoverageSalaryMultiplier(BaseModel):
    r"""The coverage amount as a multiple of the employee's salary. Only applicable for Group Term Life benefits. Note: cannot be set if coverage amount is also set."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[
        BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValue
    ] = None

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsCoverageAmountDefaultValueTypedDict(TypedDict):
    value: NotRequired[str]
    type: NotRequired[str]


class BenefitTypeRequirementsCoverageAmountDefaultValue(BaseModel):
    value: Optional[str] = None

    type: Optional[str] = None


class CoverageAmountTypedDict(TypedDict):
    r"""The amount that the employee is insured for. Note: company contribution cannot be present if coverage amount is set."""

    required: NotRequired[bool]
    editable: NotRequired[bool]
    default_value: NotRequired[
        BenefitTypeRequirementsCoverageAmountDefaultValueTypedDict
    ]
    choices: NotRequired[List[str]]


class CoverageAmount(BaseModel):
    r"""The amount that the employee is insured for. Note: company contribution cannot be present if coverage amount is set."""

    required: Optional[bool] = None

    editable: Optional[bool] = None

    default_value: Optional[BenefitTypeRequirementsCoverageAmountDefaultValue] = None

    choices: Optional[List[str]] = None


class BenefitTypeRequirementsTypedDict(TypedDict):
    r"""Benefit type requirements response"""

    employee_deduction: NotRequired[EmployeeDeductionTypedDict]
    r"""The amount to be deducted, per pay period, from the employee's pay."""
    contribution: NotRequired[BenefitTypeRequirementsContributionTypedDict]
    r"""An object representing the type and value of the company contribution."""
    deduct_as_percentage: NotRequired[DeductAsPercentageTypedDict]
    r"""Whether the employee deduction amount should be treated as a percentage to be deducted from each payroll."""
    catch_up: NotRequired[CatchUpTypedDict]
    r"""Whether the employee should use a benefit’s 'catch up' rate. Only Roth 401k and 401k benefits use this value for employees over 50."""
    limit_option: NotRequired[LimitOptionTypedDict]
    r"""Some benefits require additional information to determine their limit. For example, for an HSA benefit, the limit option should be either 'Family' or 'Individual'. For a Dependent Care FSA benefit, the limit option should be either 'Joint Filing or Single' or 'Married and Filing Separately'."""
    company_contribution_annual_maximum: NotRequired[
        CompanyContributionAnnualMaximumTypedDict
    ]
    r"""The maximum company contribution amount per year. A null value signifies no limit."""
    coverage_salary_multiplier: NotRequired[CoverageSalaryMultiplierTypedDict]
    r"""The coverage amount as a multiple of the employee's salary. Only applicable for Group Term Life benefits. Note: cannot be set if coverage amount is also set."""
    coverage_amount: NotRequired[CoverageAmountTypedDict]
    r"""The amount that the employee is insured for. Note: company contribution cannot be present if coverage amount is set."""


class BenefitTypeRequirements(BaseModel):
    r"""Benefit type requirements response"""

    employee_deduction: Optional[EmployeeDeduction] = None
    r"""The amount to be deducted, per pay period, from the employee's pay."""

    contribution: Optional[BenefitTypeRequirementsContribution] = None
    r"""An object representing the type and value of the company contribution."""

    deduct_as_percentage: Optional[DeductAsPercentage] = None
    r"""Whether the employee deduction amount should be treated as a percentage to be deducted from each payroll."""

    catch_up: Optional[CatchUp] = None
    r"""Whether the employee should use a benefit’s 'catch up' rate. Only Roth 401k and 401k benefits use this value for employees over 50."""

    limit_option: Optional[LimitOption] = None
    r"""Some benefits require additional information to determine their limit. For example, for an HSA benefit, the limit option should be either 'Family' or 'Individual'. For a Dependent Care FSA benefit, the limit option should be either 'Joint Filing or Single' or 'Married and Filing Separately'."""

    company_contribution_annual_maximum: Optional[CompanyContributionAnnualMaximum] = (
        None
    )
    r"""The maximum company contribution amount per year. A null value signifies no limit."""

    coverage_salary_multiplier: Optional[CoverageSalaryMultiplier] = None
    r"""The coverage amount as a multiple of the employee's salary. Only applicable for Group Term Life benefits. Note: cannot be set if coverage amount is also set."""

    coverage_amount: Optional[CoverageAmount] = None
    r"""The amount that the employee is insured for. Note: company contribution cannot be present if coverage amount is set."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_app_integration.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RehireEmploymentStatus(str, Enum):
    r"""The employee's employment status. Supplying an invalid option will set the employment_status to *not_set*."""

    PART_TIME = "part_time"
    FULL_TIME = "full_time"
    PART_TIME_ELIGIBLE = "part_time_eligible"
    VARIABLE = "variable"
    SEASONAL = "seasonal"
    NOT_SET = "not_set"


class RehireTypedDict(TypedDict):
    r"""Example response"""

    version: NotRequired[str]
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/versioning#object-layer) for information on how to use this field."""
    effective_date: NotRequired[str]
    r"""The day when the employee returns to work."""
    file_new_hire_report: NotRequired[bool]
    r"""The boolean flag indicating whether Gusto will file a new hire report for the employee."""
    work_location_uuid: NotRequired[str]
    r"""The uuid of the employee's work location."""
    employment_status: NotRequired[RehireEmploymentStatus]
    r"""The employee's employment status. Supplying an invalid option will set the employment_status to *not_set*."""
    two_percent_shareholder: NotRequired[bool]
    r"""Whether the employee is a two percent shareholder of the company. This field only applies to companies with an S-Corp entity type."""
    employee_uuid: NotRequired[str]
    r"""The UUID of the employee."""
    active: NotRequired[bool]
    r"""Whether the employee's rehire has gone into effect."""


class Rehire(BaseModel):
    r"""Example response"""

    version: Optional[str] = None
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/versioning#object-layer) for information on how to use this field."""

    effective_date: Optional[str] = None
    r"""The day when the employee returns to work."""

    file_new_hire_report: Optional[bool] = None
    r"""The boolean flag indicating whether Gusto will file a new hire report for the employee."""

    work_location_uuid: Optional[str] = None
    r"""The uuid of the employee's work location."""

    employment_status: Optional[RehireEmploymentStatus] = None
    r"""The employee's employment status. Supplying an invalid option will set the employment_status to *not_set*."""

    two_percent_shareholder: Optional[bool] = None
    r"""Whether the employee is a two percent shareholder of the company. This field only applies to companies with an S-Corp entity type."""

    employee_uuid: Optional[str] = None
    r"""The UUID of the employee."""

    active: Optional[bool] = None
    r"""Whether the employee's rehire has gone into effect."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import date
from gusto_app_integration.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MinimumWageTypedDict(TypedDict):
    r"""Representation of a Minimum Wage"""

    uuid: str
    r"""unique identifier of a minimum wage"""
    wage: str
    r"""The wage rate for a minimum wage record. Represented as a float, e.g. \"15.0\"."""
    wage_type: str
    r"""The type of wage the minimum wage applies to, e.g. \"Regular\", \"Regular-Industry-Specific\"."""
    effective_date: date
    r"""The date the minimum wage rule is effective on."""
    authority: str
    r"""The governing authority that created the minimum wage, e.g. \"City\", \"State\", or \"Federal\"."""
    notes: NotRequired[str]
    r"""Description of parties the minimum wage applies to."""


class MinimumWage(BaseModel):
    r"""Representation of a Minimum Wage"""

    uuid: str
    r"""unique identifier of a minimum wage"""

    wage: str
    r"""The wage rate for a minimum wage record. Represented as a float, e.g. \"15.0\"."""

    wage_type: str
    r"""The type of wage the minimum wage applies to, e.g. \"Regular\", \"Regular-Industry-Specific\"."""

    effective_date: date
    r"""The date the minimum wage rule is effective on."""

    authority: str
    r"""The governing authority that created the minimum wage, e.g. \"City\", \"State\", or \"Federal\"."""

    notes: Optional[str] = None
    r"""Description of parties the minimum wage applies to."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_app_integration.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ContractorPaymentForGroupPaymentMethod(str, Enum):
    r"""The payment method."""

    DIRECT_DEPOSIT = "Direct Deposit"
    CHECK = "Check"
    HISTORICAL_PAYMENT = "Historical Payment"
    CORRECTION_PAYMENT = "Correction Payment"


class ContractorPaymentForGroupStatus(str, Enum):
    r"""The status of the contractor payment.  Will transition to `Funded` during payments processing if the payment should be funded, i.e. has `Direct Deposit` for payment method. Contractors payments with `Check` payment method will remain `Unfunded`."""

    FUNDED = "Funded"
    UNFUNDED = "Unfunded"


class ContractorPaymentForGroupWageType(str, Enum):
    r"""The wage type for the payment."""

    HOURLY = "Hourly"
    FIXED = "Fixed"


class ContractorPaymentForGroupTypedDict(TypedDict):
    r"""The representation of a single contractor payment."""

    uuid: NotRequired[str]
    r"""The unique identifier of the contractor payment in Gusto."""
    contractor_uuid: NotRequired[str]
    r"""The UUID of the contractor."""
    bonus: NotRequired[str]
    r"""The bonus amount in the payment."""
    hours: NotRequired[str]
    r"""The number of hours worked for the payment."""
    payment_method: NotRequired[ContractorPaymentForGroupPaymentMethod]
    r"""The payment method."""
    reimbursement: NotRequired[str]
    r"""The reimbursement amount in the payment."""
    status: NotRequired[ContractorPaymentForGroupStatus]
    r"""The status of the contractor payment.  Will transition to `Funded` during payments processing if the payment should be funded, i.e. has `Direct Deposit` for payment method. Contractors payments with `Check` payment method will remain `Unfunded`."""
    hourly_rate: NotRequired[str]
    r"""The rate per hour worked for the payment."""
    may_cancel: NotRequired[bool]
    r"""Determine if the contractor payment can be cancelled."""
    wage: NotRequired[str]
    r"""The fixed wage of the payment, regardless of hours worked."""
    wage_type: NotRequired[ContractorPaymentForGroupWageType]
    r"""The wage type for the payment."""
    wage_total: NotRequired[str]
    r"""(hours * hourly_rate) + wage + bonus"""


class ContractorPaymentForGroup(BaseModel):
    r"""The representation of a single contractor payment."""

    uuid: Optional[str] = None
    r"""The unique identifier of the contractor payment in Gusto."""

    contractor_uuid: Optional[str] = None
    r"""The UUID of the contractor."""

    bonus: Optional[str] = None
    r"""The bonus amount in the payment."""

    hours: Optional[str] = None
    r"""The number of hours worked for the payment."""

    payment_method: Optional[ContractorPaymentForGroupPaymentMethod] = None
    r"""The payment method."""

    reimbursement: Optional[str] = None
    r"""The reimbursement amount in the payment."""

    status: Optional[ContractorPaymentForGroupStatus] = None
    r"""The status of the contractor payment.  Will transition to `Funded` during payments processing if the payment should be funded, i.e. has `Direct Deposit` for payment method. Contractors payments with `Check` payment method will remain `Unfunded`."""

    hourly_rate: Optional[str] = None
    r"""The rate per hour worked for the payment."""

    may_cancel: Optional[bool] = None
    r"""Determine if the contractor payment can be cancelled."""

    wage: Optional[str] = None
    r"""The fixed wage of the payment, regardless of hours worked."""

    wage_type: Optional[ContractorPaymentForGroupWageType] = None
    r"""The wage type for the payment."""

    wage_total: Optional[str] = None
    r"""(hours * hourly_rate) + wage + bonus"""
